===============================
DBaaS Flipper
===============================

.. image:: https://badge.fury.io/py/dbaas-flipper.png
    :target: http://badge.fury.io/py/dbaas-flipper
    
.. image:: https://travis-ci.org/felippemr/dbaas-flipper.png?branch=master
        :target: https://travis-ci.org/felippemr/dbaas-flipper

.. image:: https://pypip.in/d/dbaas-flipper/badge.png
        :target: https://pypi.python.org/pypi/dbaas-flipper


Flipper integration 4 DBaaS

* Free software: BSD license
* Documentation: http://dbaas-flipper.rtfd.org.

Features
--------

* TODO